==> vue-mny-0.1.3.tgz: package/vue-mny.js <==
module.exports = {
  install: function(Vue, optionsUser) {
    const extend = function() {
      let extended = {},
        deep = false,
        i = 0,
        length = arguments.length;
      if (Object.prototype.toString.call(arguments[0]) === "[object Boolean]") {
        deep = arguments[0];
        i++;
      }
      let merge = function(obj) {
        for (let prop in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, prop)) {
            if (
              deep &&
              Object.prototype.toString.call(obj[prop]) === "[object Object]"
            ) {
              extended[prop] = extend(true, extended[prop], obj[prop]);
            } else {
              extended[prop] = obj[prop];
            }
          }
        }
      };
      for (; i < length; i++) {
        let obj = arguments[i];
        merge(obj);
      }
      return extended;
    };

    const optionsGlobal = extend(
      {
        locale: "en-US",
        style: "currency",
        currency: "USD",
        currencyDisplay: "symbol",

        env: "prod"
      },
      optionsUser
    );

    const moneyfy = (raw, options) => {
      try {
        return new Intl.NumberFormat(options.locale, {
          style: options.style,
          currency: options.currency,
          currencyDisplay: options.currencyDisplay
        }).format(raw / 100);
      } catch (err) {
        if (options.env == "dev") console.error(err);
        return "[oeps]";
      }
    };

    const vuemny = (str, optionsFilter = {}, optionsForce = {}) => {
      return moneyfy(str, extend(optionsGlobal, optionsFilter, optionsForce));
    };

    Vue.directive("mny", function(el, binding) {
      el.innerHTML =
        binding.value instanceof Object
          ? vuemny(binding.value.input, binding.value)
          : vuemny(binding.value);
    });
  }
};

==> vue-mny-0.2.1.tgz: package/vue-mny.js <==
module.exports = {
  install: function(Vue, optionsUser) {
    const extend = function() {
      let out = {};
      for (let i = 0, len = arguments.length; i < len; ++i) {
        let obj = arguments[i];
        if (!obj) continue;
        for (let key in obj) {
          if (!obj.hasOwnProperty(key) || !obj[key]) continue;
          if (Object.prototype.toString.call(obj[key]) === "[object Object]") {
            out[key] = extend(out[key], obj[key]);
            continue;
          }
          out[key] = obj[key];
        }
      }
      return out;
    };

    const optionsGlobal = extend(
      {
        locale: "en-US",
        style: "currency",
        currency: "USD",
        currencyDisplay: "symbol",

        env: "prod"
      },
      optionsUser
    );

    const moneyfy = (raw, options) => {
      try {
        return new Intl.NumberFormat(options.locale, {
          style: options.style,
          currency: options.currency,
          currencyDisplay: options.currencyDisplay
        }).format(raw / 100);
      } catch (err) {
        if (options.env == "dev") console.error(err);
        return "[oeps]";
      }
    };

    const vuemny = (str, optionsFilter = {}, optionsForce = {}) => {
      return moneyfy(str, extend(optionsGlobal, optionsFilter, optionsForce));
    };

    Vue.directive("mny", function(el, binding) {
      el.innerHTML =
        binding.value instanceof Object
          ? vuemny(binding.value.input, binding.value)
          : vuemny(binding.value);
    });
  }
};
